@@ -5,7 +5,25 @@ EnvironmentHelper.update("URL_VARIANT", RandomHelper.integer(minimum=0, maximum=
 log.debug(log.debug, f'variant: {EnvironmentHelper.get("URL_VARIANT")}')
 
 from python_helper import TestHelper
-TestHelper.run(__file__)
+# TestHelper.run(__file__)
+TestHelper.run(
+    __file__,
+    runOnly = [
+        # 'SerializerTest.getClassRole',
+        # 'SerializerTest.importResource',
+        'SerializerTest.convertFromObjectToObject'
+
+        # 'SerializerTest.convertFromObjectToObject_whenTargetClassIsList',
+        # 'SerializerTest.isModelTest',
+        # 'SerializerTest.isJsonifyable',
+        # 'SerializerTest.jsonifyIt',
+        # 'SerializerTest.fromDtoToModel',
+        # 'SerializerTest.fromModelToDto',
+        # 'SerializerTest.convertFromJsonToObject_whenThereAreEnums',
+        # 'SerializerTest.convertFromObjectToObject_weirdIdList',
+        # 'SerializerTest.convertFromJsonToObject_nativeClassAtributeList'
+    ]
+)
 # TestHelper.run(
 #     __file__,
 #     runOnly = [
